Clients
=======

Client for v3 Lite
------------------

.. automodule:: duedil.v3lite
    :members:
    :undoc-members:


Client for v3 Pro
-----------------

.. automodule:: duedil.v3pro
    :members:
    :undoc-members:
    :inherited-members:

